@@ -1,4 +1,5 @@
 bcont23twoParC <- function(params, respvec, VC, ps, AT = FALSE){
+p1 <- p2 <- pdf1 <- pdf2 <- c.copula.be2 <- c.copula.be1 <- c.copula2.be1be2 <- NA
 
     l.ln <- NULL
 
@@ -6,8 +7,6 @@ bcont23twoParC <- function(params, respvec, VC, ps, AT = FALSE){
     eta2 <- VC$X2%*%params[(VC$X1.d2 + 1):(VC$X1.d2 + VC$X2.d2)]
     nu <- etad <- etas1 <- etas2 <- etan <- etan1 <- etan2 <- NULL 
   
-    epsilon <- sqrt(.Machine$double.eps) 
-    max.p   <- 0.9999999
     
     
   if(is.null(VC$X3)){  
@@ -43,7 +42,7 @@ bcont23twoParC <- function(params, respvec, VC, ps, AT = FALSE){
     sigma22    <- sstr2$vrb 
     
 
-sstr2 <- esp.tr(nu2.st, VC$margins[2])  
+sstr2 <- enu.tr(nu2.st, VC$margins[2])  
 nu2.st <- sstr2$vrb.st 
 nu2    <- sstr2$vrb 
 
@@ -62,8 +61,8 @@ teta    <- resT$teta
 ##################
 ##################
 
-  dHs1 <- distrHs(respvec$y1, eta1, sigma21, sigma21.st,   1,      1, margin2=VC$margins[1], naive = FALSE)
-  dHs2 <- distrHs(respvec$y2, eta2, sigma22, sigma22.st, nu2, nu2.st, margin2=VC$margins[2], naive = FALSE)
+  dHs1 <- distrHs(respvec$y1, eta1, sigma21, sigma21.st,   1,      1, margin2=VC$margins[1], naive = FALSE, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
+  dHs2 <- distrHs(respvec$y2, eta2, sigma22, sigma22.st, nu2, nu2.st, margin2=VC$margins[2], naive = FALSE, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
 
   pdf1 <- dHs1$pdf2
   pdf2 <- dHs2$pdf2
@@ -71,7 +70,7 @@ teta    <- resT$teta
   p1 <- dHs1$p2
   p2 <- dHs2$p2
   
-  dH <- copgHsAT(p1, p2, teta, VC$BivD, Ln = TRUE, par2 = nu)
+  dH <- copgHsAT(p1, p2, teta, VC$BivD, Ln = TRUE, par2 = nu, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
 
   c.copula2.be1be2 <- dH$c.copula2.be1be2
   
@@ -432,12 +431,12 @@ if(VC$extra.regI == "sED") H <- regH(H, type = 2)
 if( VC$margins[1] == "LN" || VC$margins[2] == "LN"){
   
   
-  if(VC$margins[1] == "LN") dHs1 <- distrHsAT(exp(respvec$y1), eta1, sigma21, 1, margin2 = VC$margins[1])
+  if(VC$margins[1] == "LN") dHs1 <- distrHsAT(exp(respvec$y1), eta1, sigma21, 1, margin2 = VC$margins[1], min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
 
   pdf1 <- dHs1$pdf2
   p1   <- dHs1$p2
  
-  dH <- copgHsAT(p1, p2, teta, VC$BivD, Ln = TRUE, par2 = nu)
+  dH <- copgHsAT(p1, p2, teta, VC$BivD, Ln = TRUE, par2 = nu, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
 
   c.copula2.be1be2 <- dH$c.copula2.be1be2  
   
@@ -452,7 +451,11 @@ if( VC$margins[1] == "LN" || VC$margins[2] == "LN"){
   
          list(value=res, gradient=G, hessian=H, S.h=S.h, S.h1=S.h1, S.h2=S.h2, l=S.res, l.par=l.par, ps = ps, l.ln = l.ln,
               eta1=eta1, eta2=eta2, etad=etad, etas1 = etas1, etas2 = etas2, etan = etan, etan2 = etan2, 
-              BivD=VC$BivD, p1 = p1, p2 = p2,
+              BivD=VC$BivD, 
+                            p1 = p1, p2 = p2, pdf1 = pdf1, pdf2 = pdf2,          
+	                    c.copula.be2 = c.copula.be2,
+	                    c.copula.be1 = c.copula.be1,
+              c.copula2.be1be2 = c.copula2.be1be2, 
               dl.dbe1          =dl.dbe1,       
               dl.dbe2          =dl.dbe2,       
               dl.dsigma21.st   =dl.dsigma21.st,
