@@ -51,7 +51,8 @@ bprobgHsDiscr2ROY <- function(params, respvec, VC, ps, AT = FALSE){
       
 #######################    
 
- dHs <- distrHsDiscr(respvec$y2, eta2, sigma1, sigma1.st, nu = 1, nu.st = 1, margin2 = VC$margins[2], naive = FALSE, y2m = VC$y2m, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
+ dHs <- distrHsDiscr(respvec$y2, eta2, sigma1, sigma1.st, nu = 1, nu.st = 1, margin2 = VC$margins[2], naive = FALSE, y2m = VC$y2m, min.dn = VC$min.dn, 
+                     min.pr = VC$min.pr, max.pr = VC$max.pr, left.trunc = VC$left.trunc1)
    
    
  pdf2.M2                         <- dHs$pdf2
@@ -69,7 +70,8 @@ bprobgHsDiscr2ROY <- function(params, respvec, VC, ps, AT = FALSE){
    
    
    
-  dHs <- distrHsDiscr(respvec$y3, eta3, sigma2, sigma2.st, nu = 1, nu.st = 1, margin2 = VC$margins[3], naive = FALSE, y2m = VC$y3m, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
+  dHs <- distrHsDiscr(respvec$y3, eta3, sigma2, sigma2.st, nu = 1, nu.st = 1, margin2 = VC$margins[3], naive = FALSE, y2m = VC$y3m, min.dn = VC$min.dn, 
+                      min.pr = VC$min.pr, max.pr = VC$max.pr, left.trunc = VC$left.trunc2)
    
    
  pdf2.M3                         <- dHs$pdf2
