@@ -21,7 +21,7 @@ if(type == "ROY"){
 if(type == "biv"){
 
   if(M$Model=="B" && margins[2] %in% M$bl  &&  is.null(M$theta.fx) && is.null(M$K2)) func.opt <- bprobgHs         #
-  if(M$Model=="B" && margins[2] %in% M$bl  && !is.null(M$theta.fx) && is.null(M$K2)) func.opt <- bprobgHsFixTheta # 
+  #if(M$Model=="B" && margins[2] %in% M$bl  && !is.null(M$theta.fx) && is.null(M$K2)) func.opt <- bprobgHsFixTheta # 
 
   if(M$Model=="B" && margins[2] %in% M$m1d  ) {func.opt <- bprobgHsDiscr1 ; func.optUniv <- bprobgHsContUniv}   
   if(M$Model=="B" && margins[2] %in% M$m2d  ) {func.opt <- bprobgHsDiscr2 ; func.optUniv <- bprobgHsContUniv} 
@@ -44,6 +44,10 @@ if(type == "biv"){
   
 if(type == "copR"){
 
+  if(margins[1] %in% M$m1d && margins[2] %in% M$m2) func.opt  <- bdiscrcont12
+  if(margins[1] %in% M$m1d && margins[2] %in% M$m3) func.opt  <- bdiscrcont13
+  if(margins[1] %in% M$m2d && margins[2] %in% M$m2) func.opt  <- bdiscrcont
+  if(margins[1] %in% M$m2d && margins[2] %in% M$m3) func.opt  <- bdiscrcont23
   
   if(margins[1] %in% M$m1d && margins[2] %in% M$m1d) func.opt  <- bdiscrdiscr11 
   if(margins[1] %in% M$m1d && margins[2] %in% M$m2d) func.opt  <- bdiscrdiscr12
@@ -84,7 +88,9 @@ if(type == "copR"){
   
   
   
-  # if(margins[1] %in% M$m2 && margins[2] %in% M$bl && M$surv == TRUE)  func.opt <- bcontSurvGcont2Surv # not really used
+   if(margins[1] %in% M$m2 && margins[2] %in% M$bl && M$surv == TRUE)  func.opt <- bcontSurvGcont2Surv 
+   if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$surv == TRUE && M$end.surv == TRUE)  func.opt <- bcontSurvGBIN
+
   #if(margins[1] %in% M$m3 && margins[2] %in% M$bl && M$surv == TRUE)  func.opt <- bcontSurvGcont3Surv # not really used
   
   if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$surv == TRUE && M$dep.cens == TRUE &&  is.null(M$c3)) func.opt <- bcontSurvGDep
@@ -102,7 +108,7 @@ if(type == "copSS"){
   
   if(margins[2] %in% M$m1d   ) func.opt <- bprobgHsDiscr1SS
   if(margins[2] %in% M$m2d   ) func.opt <- bprobgHsDiscr2SS  
-  #if(margins[2] %in% c("TW") ) func.opt <- bprobgHsCont3binTWSS  
+  if(margins[2] %in% c("TW") ) func.opt <- bprobgHsCont3binTWSS  
   
 
 }
