@@ -10,6 +10,7 @@ sp7 <- SP$sp7
 sp8 <- SP$sp8
 sp9 <- SP$sp9
 
+# this function should be cleaner as there are many useless reps but ok for now
 
 if(type == "ROY"){
 
@@ -157,28 +158,13 @@ if(type == "biv"){
   
 
 
-if(M$BivD != "T"){
   
   if( l.flist == 2 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, VC$i.rho)              # PO, N, DAGUM etc
   if( l.flist == 3 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, GAM$gam3$coefficients) # PO only
   if( l.flist == 4 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, GAM$gam4$coefficients) # N
   if( l.flist == 5 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, GAM$gam5$coefficients) # DAGUM
+  if( l.flist == 6 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, GAM$gam6$coefficients) # DAGUM
   
-}
-
-if(M$BivD == "T"){
-  
-  if( l.flist == 2 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, VC$dof.st, VC$i.rho)                          # PO, N, DAGUM etc
-  if( l.flist == 4 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, GAM$gam3$coefficients, GAM$gam4$coefficients) # PO only
-  if( l.flist == 5 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, GAM$gam4$coefficients, GAM$gam5$coefficients) # N
-  if( l.flist == 6 ) start.v <- c(GAM$gam1$coefficients, gamlss2$coefficients, GAM$gam5$coefficients, GAM$gam6$coefficients) # DAGUM
-  
-}
-
-
-
-
-
 
 if( margins[2] %in% c(M$m1d) ) if(VC$l.sp2 != 0) sp2 <- gamlss2$sp[1:VC$l.sp2] 
                                 
@@ -217,6 +203,26 @@ if(type == "copR"){
   }
   
   
+  if(margins[1] %in% c(M$bl) && margins[2] %in% c(M$bl) && M$surv == TRUE){#  && M$end.surv == TRUE){
+  
+  b1 <- gamlss1$coefficients[1:VC$X1.d2]
+  b2 <- gamlss2$coefficients[1:VC$X2.d2]
+ 
+  if(l.flist == 2) start.v <- c(b1, b2, VC$i.rho)
+  if(l.flist  > 2) start.v <- c(b1, b2, GAM$gam3$coefficients)
+  
+  names(start.v) <- nstv
+  
+  if( VC$l.sp1 != 0 ) sp1 <- gamlss1$sp
+  if( VC$l.sp2 != 0 ) sp2 <- gamlss2$sp
+  
+  }  
+  
+  
+  
+  
+  
+  
   
   if(margins[1] %in% c(M$m3) && margins[2] %in% c(M$bl) && l.flist == 2 && M$surv == TRUE){
   
@@ -252,6 +258,9 @@ if(type == "copR"){
   
   
   
+  
+  
+  
   if(margins[1] %in% c(M$m3) && margins[2] %in% c(M$bl) && l.flist > 2 && M$surv == TRUE){
   
   b1 <- gamlss1$coefficients[1:VC$X1.d2]
@@ -376,7 +385,7 @@ if(type == "copR"){
   
 
   
-  if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% c(M$m2,M$m2d) && l.flist == 2 && M$BivD != "T"){
+  if((margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% c(M$m2,M$m2d) && l.flist == 2 && M$BivD != "T") || (margins[1] %in% c(M$m2d) && margins[2] %in% c(M$m2d) && l.flist == 2 && M$BivD == "T")){
   
   b1 <- gamlss1$coefficients[1:VC$X1.d2]
   s1 <- gamlss1$coefficients[VC$X1.d2+1]
@@ -390,14 +399,16 @@ if(type == "copR"){
   
   }
   
-  if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% c(M$m2,M$m2d) && l.flist > 2 && M$BivD != "T"){
+  
+  
+  if((margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% c(M$m2,M$m2d) && l.flist > 2 && M$BivD != "T") || (margins[1] %in% c(M$m2d) && margins[2] %in% c(M$m2d) && l.flist > 2 && M$BivD == "T")){
   
   b1 <- gamlss1$coefficients[1:VC$X1.d2]
   s1 <- gamlss1$coefficients[(VC$X1.d2+1):(VC$X1.d2+VC$X3.d2)]
   b2 <- gamlss2$coefficients[1:VC$X2.d2]
   s2 <- gamlss2$coefficients[(VC$X2.d2+1):(VC$X2.d2+VC$X4.d2)]  
  
-  start.v  <- c(b1, b2, s1, s2, GAM$gam5$coefficients); names(start.v) <- nstv  
+  start.v  <- c(b1, b2, s1, s2, GAM$gam5$coefficients); names(start.v) <- nstv # dropped gam6 here   
   
   if( VC$l.sp1 != 0 ) sp1 <- gamlss1$sp[1:VC$l.sp1]
   if( VC$l.sp3 != 0 ) sp3 <- gamlss1$sp[(VC$l.sp1 + 1):(VC$l.sp1 + VC$l.sp3)]
@@ -408,10 +419,11 @@ if(type == "copR"){
   } 
   
   
+   
   
-  
-  
-  if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% c(M$m2,M$m2d) && l.flist == 2 && M$BivD == "T"){
+
+    
+  if(margins[1] %in% c(M$m2) && margins[2] %in% c(M$m2) && l.flist == 2 && M$BivD == "T"){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[VC$X1.d2+1]
@@ -423,9 +435,14 @@ if(type == "copR"){
     if( VC$l.sp1 != 0 ) sp1 <- gamlss1$sp
     if( VC$l.sp2 != 0 ) sp2 <- gamlss2$sp
     
-    }
+    }    
     
-    if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% c(M$m2,M$m2d) && l.flist > 2 && M$BivD == "T"){
+    
+    
+
+  
+  
+     if(margins[1] %in% c(M$m2) && margins[2] %in% c(M$m2) && l.flist > 2 && M$BivD == "T"){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[(VC$X1.d2+1):(VC$X1.d2+VC$X3.d2)]
@@ -440,10 +457,7 @@ if(type == "copR"){
     if( VC$l.sp2 != 0 ) sp2 <- gamlss2$sp[1:VC$l.sp2]
     if( VC$l.sp4 != 0 ) sp4 <- gamlss2$sp[(VC$l.sp2 + 1):(VC$l.sp2 + VC$l.sp4)]  
   
-  }  
-  
-  
-  
+  }   
   
   
   
@@ -539,7 +553,7 @@ if(type == "copR"){
   #
   #
   
-  if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% M$m3 && l.flist == 2 && M$BivD != "T"){
+  if((margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% M$m3 && l.flist == 2 && M$BivD != "T") || (margins[1] %in% c(M$m2d) && margins[2] %in% M$m3 && l.flist == 2 && M$BivD == "T")){
   
   b1 <- gamlss1$coefficients[1:VC$X1.d2]
   s1 <- gamlss1$coefficients[VC$X1.d2+1]
@@ -554,7 +568,10 @@ if(type == "copR"){
   
   }  
   
-  if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% M$m3 && l.flist > 2 && M$BivD != "T"){
+  
+  
+  
+  if((margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% M$m3 && l.flist > 2 && M$BivD != "T") || (margins[1] %in% c(M$m2d) && margins[2] %in% M$m3 && l.flist > 2 && M$BivD == "T")){
   
   b1 <- gamlss1$coefficients[1:VC$X1.d2]
   s1 <- gamlss1$coefficients[(VC$X1.d2+1):(VC$X1.d2+VC$X3.d2)] 
@@ -576,10 +593,9 @@ if(type == "copR"){
   
   
   
-  
-  
-  
-  if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% M$m3 && l.flist == 2 && M$BivD == "T"){
+    
+    
+  if(margins[1] %in% c(M$m2) && margins[2] %in% M$m3 && l.flist == 2 && M$BivD == "T"){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[VC$X1.d2+1]
@@ -592,11 +608,14 @@ if(type == "copR"){
     if( VC$l.sp1 != 0 ) sp1 <- gamlss1$sp
     if( VC$l.sp2 != 0 ) sp2 <- gamlss2$sp
     
-    } 
+    }     
     
     
     
-    if(margins[1] %in% c(M$m2,M$m2d) && margins[2] %in% M$m3 && l.flist > 2 && M$BivD == "T"){
+
+  
+
+    if(margins[1] %in% c(M$m2) && margins[2] %in% M$m3 && l.flist > 2 && M$BivD == "T"){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[(VC$X1.d2+1):(VC$X1.d2+VC$X3.d2)] 
@@ -614,9 +633,7 @@ if(type == "copR"){
     if( VC$l.sp4 != 0 ) sp4 <- gamlss2$sp[(VC$l.sp2 + 1):(VC$l.sp2 + VC$l.sp4)]  
     if( VC$l.sp5 != 0 ) sp5 <- gamlss2$sp[(VC$l.sp2 + VC$l.sp4 + 1):(VC$l.sp2 + VC$l.sp4 + VC$l.sp5)]  
     
-  }
-  
-  
+  }  
   
   
   
@@ -624,7 +641,7 @@ if(type == "copR"){
   #
   #  
   
-  if(margins[1] %in% M$m3 && margins[2] %in% c(M$m2,M$m2d) && l.flist == 2 && M$BivD != "T"){
+  if((margins[1] %in% M$m3 && margins[2] %in% c(M$m2,M$m2d) && l.flist == 2 && M$BivD != "T") || (margins[1] %in% M$m3 && margins[2] %in% c(M$m2d) && l.flist == 2 && M$BivD == "T")){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[VC$X1.d2+1]
@@ -639,7 +656,10 @@ if(type == "copR"){
     
     }  
     
-  if(margins[1] %in% M$m3 && margins[2] %in% c(M$m2,M$m2d) && l.flist > 2 && M$BivD != "T"){
+    
+    
+    
+  if((margins[1] %in% M$m3 && margins[2] %in% c(M$m2,M$m2d) && l.flist > 2 && M$BivD != "T") || (margins[1] %in% M$m3 && margins[2] %in% c(M$m2d) && l.flist > 2 && M$BivD == "T")){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[(VC$X1.d2+1):(VC$X1.d2+VC$X3.d2)]
@@ -656,13 +676,12 @@ if(type == "copR"){
   if( VC$l.sp2 != 0 ) sp2 <- gamlss2$sp[1:VC$l.sp2]
   if( VC$l.sp4 != 0 ) sp4 <- gamlss2$sp[(VC$l.sp2 + 1):(VC$l.sp2 + VC$l.sp4)]  
    
-    }   
+    }  
     
     
+   
     
-    
-    
-  if(margins[1] %in% M$m3 && margins[2] %in% c(M$m2,M$m2d) && l.flist == 2 && M$BivD == "T"){
+  if(margins[1] %in% M$m3 && margins[2] %in% c(M$m2) && l.flist == 2 && M$BivD == "T"){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[VC$X1.d2+1]
@@ -677,9 +696,11 @@ if(type == "copR"){
     
     }  
     
-    
-    
-  if(margins[1] %in% M$m3 && margins[2] %in% c(M$m2,M$m2d) && l.flist > 2 && M$BivD == "T"){
+
+
+
+
+  if(margins[1] %in% M$m3 && margins[2] %in% c(M$m2) && l.flist > 2 && M$BivD == "T"){
     
     b1 <- gamlss1$coefficients[1:VC$X1.d2]
     s1 <- gamlss1$coefficients[(VC$X1.d2+1):(VC$X1.d2+VC$X3.d2)]
@@ -701,6 +722,7 @@ if(type == "copR"){
     
     
     
+    
 }    
     
   #
