@@ -1,11 +1,13 @@
-jc.probs5 <- function(x, y1, y2, newdata, type, cond, intervals, n.sim, prob.lev, cont1par, cont2par, cont3par, bin.link, min.pr, max.pr){
+jc.probs5 <- function(x, y1, y2, newdata, type, cond, intervals, n.sim, prob.lev, cont1par, cont2par, cont3par, bin.link, min.pr, max.pr, tau.res = FALSE){
 
 ######################################################################################################
 
 CIp12 <- p12s <- nu1 <- nu1s <- nus <- nu <- NULL
-CIkt <- tau <- NULL
+CIkt <- tau <- theta <- CItheta <- NULL
 dof <- x$dof
 
+p12s  <- matrix(0, 1, 2) 
+
 ######################################################################################################
 
 
@@ -170,10 +172,12 @@ if(length(theta) == 1) p12[x$teta.ind2] <- copgHsCond(p1[x$teta.ind2], p2[x$teta
 
 # kendalls' tau
 
-if(x$BivD %in% x$BivD2)    {x$SemiParFit <- x; tau <- Reg2Copost(x$SemiParFit, x$VC, theta)$tau } 
-if(!(x$BivD %in% x$BivD2)) tau <- ass.ms(x$VC$BivD, x$VC$nCa, theta)$tau
-
+if(x$BivD %in% x$BivD2 && tau.res == TRUE)    {x$SemiParFit <- x; tau <- Reg2Copost(x$SemiParFit, x$VC, theta, tau.res = tau.res)$tau} 
+if(!(x$BivD %in% x$BivD2) && tau.res == TRUE) tau <- theta2tau(x$VC$BivD, x$VC$nCa, theta, tau.res = tau.res)$tau
 
+if(x$BivD %in% x$BivD2)    {x$SemiParFit <- x; theta <- Reg2Copost(x$SemiParFit, x$VC, theta, tau.res = FALSE)$theta} 
+if(!(x$BivD %in% x$BivD2)) theta <- theta2tau(x$VC$BivD, x$VC$nCa, theta, tau.res = FALSE)$theta
+     
 
 ############################## 
 
@@ -196,19 +200,19 @@ if(x$margins[1] %in% cont3par) nu1s <- enu.tr(X4%*%t(bs[,(x$X1.d2 + x$X2.d2 + x$
                     
 if(  is.null(x$X3) ){
    if(x$margins[1] %in% cont3par){
-            sigma21s <- esp.tr(bs[, lf - 2], x$VC$margins[1])$vrb; nu1s <- enu.tr(bs[, lf - 1], x$VC$margins[1])$vrb 
-            sigma21s <- matrix(rep(sigma21s, each = dim(eta1s)[1]), ncol = n.sim, byrow = FALSE)
-            nu1s     <- matrix(rep(nu1s, each = dim(eta1s)[1]), ncol = n.sim, byrow = FALSE)
+            sigma21s <- esp.tr(bs[, x$X1.d2 + x$X2.d2 + 1], x$VC$margins[1])$vrb; nu1s <- enu.tr(bs[, x$X1.d2 + x$X2.d2 + 1 + 1], x$VC$margins[1])$vrb 
+
+
                                  }
    
    if(x$margins[1] %in% cont2par){
-                     sigma21s <- esp.tr(bs[, lf - 1], x$VC$margins[1])$vrb 
-                     sigma21s <- matrix(rep(sigma21s, each = dim(eta1s)[1]), ncol = n.sim, byrow = FALSE)
+                     sigma21s <- esp.tr(bs[, x$X1.d2 + x$X2.d2 + 1], x$VC$margins[1])$vrb 
+
                                  }
                     }                     
    
                        
-p1s <- matrix( distrHsAT(y1, eta1s, sigma21s, nu1s, x$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2 , dim(eta1s)[1], n.sim)
+p1s <- distrHsAT(y1, eta1s, sigma21s, nu1s, x$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2
 p2s <- probmS( X2%*%t(bs[,(x$X1.d2+1):(x$X1.d2+x$X2.d2)]) , x$VC$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pr
 
   
@@ -220,7 +224,7 @@ if( is.null(x$X3)  ) epds <- bs[, lf]
        
                          
 est.RHOb <- teta.tr(x$VC, epds)$teta
-if( is.null(x$X3) ) est.RHOb <- matrix(rep(est.RHOb, each = dim(p1s)[1]), ncol = n.sim, byrow = FALSE)
+
 
 ###########################   
 
@@ -229,9 +233,7 @@ if( is.null(x$X3) ) est.RHOb <- matrix(rep(est.RHOb, each = dim(p1s)[1]), ncol =
 if(cond == 0){
 
 
-if(x$VC$BivD %in% c("N","T")) p12s <- matrix(mm(BiCDF(p1s, p2s, x$nC, est.RHOb, dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ), dim(p1s)[1], n.sim) else{
-
-if(!(x$BivD %in% x$BivD2)) p12s <- matrix(mm(BiCDF(p1s, p2s, x$nC, est.RHOb, par2 = dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ), dim(p1s)[1], n.sim)
+if(!(x$BivD %in% x$BivD2)) p12s <- mm(BiCDF(p1s, p2s, x$nC, est.RHOb, par2 = dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  )
 
 if(x$BivD %in% x$BivD2){ 
 
@@ -242,7 +244,7 @@ if( length(x$teta2) != 0) p12s[x$teta.ind2,] <-  matrix(mm(BiCDF(p1s[x$teta.ind2
                       
                         }
 
-                                                                                                                        }
+                                                                                                                        
 }
 
                                                                                
@@ -250,9 +252,8 @@ if( length(x$teta2) != 0) p12s[x$teta.ind2,] <-  matrix(mm(BiCDF(p1s[x$teta.ind2
 if(cond == 1){
 
 
-if(!(x$BivD %in% x$BivD2)) p12s <-  matrix(copgHsCond(p1s, p2s, est.RHOb, dof = dof, x$BivD, min.pr = min.pr, max.pr = max.pr)$c.copula.be1, dim(p1s)[1], n.sim)
+if(!(x$BivD %in% x$BivD2)) p12s <-  copgHsCond(p1s, p2s, est.RHOb, dof = dof, x$BivD, min.pr = min.pr, max.pr = max.pr)$c.copula.be1
 
-if(x$BivD == "T") p12s <- matrix(p12s, dim(p1s)[1], n.sim)
 
 
 if(x$BivD %in% x$BivD2){
@@ -272,10 +273,7 @@ if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- copgHsCond(p1s[x$teta.ind2,], p2
 if(cond == 2){
 
 
-if(!(x$BivD %in% x$BivD2)) p12s <-  matrix(copgHsCond(p1s, p2s, est.RHOb, dof = dof, x$BivD, min.pr = min.pr, max.pr = max.pr)$c.copula.be2, dim(p1s)[1], n.sim)
-
-if(x$BivD == "T") p12s <- matrix(p12s, dim(p1s)[1], n.sim)
-
+if(!(x$BivD %in% x$BivD2)) p12s <-  copgHsCond(p1s, p2s, est.RHOb, dof = dof, x$BivD, min.pr = min.pr, max.pr = max.pr)$c.copula.be2
 
 if(x$BivD %in% x$BivD2){
 
@@ -305,13 +303,26 @@ BivDt <- x$VC$BivD
   
                          }
   
-ass.msR <- ass.ms(BivDt, nCa, est.RHOb)
-taus    <- ass.msR$tau
-if(!is.null(x$X3) && BivDt %in% c("AMH", "FGM")) taus <- matrix(taus, nrow(x$X3), nrow(bs))
-CIkt <- rowQuantiles(taus, probs = c(prob.lev/2,1-prob.lev/2), na.rm = TRUE)
+
+
+
+ass.msR <- theta2tau(BivDt, nCa, est.RHOb, tau.res = tau.res)
+if(tau.res == TRUE) taus <- ass.msR$tau
+thetas <- ass.msR$theta
+
+
+
+if(tau.res == TRUE){taus <- matrix(taus, 1, n.sim); CIkt <- rowQuantiles(taus, probs = c(prob.lev/2,1-prob.lev/2), na.rm = TRUE)}
+
+thetas <- matrix(thetas, 1, n.sim)
+CItheta <- rowQuantiles(thetas, probs = c(prob.lev/2,1-prob.lev/2), na.rm = TRUE)
+
+
+
+
 #if( is.null(x$X3) ) CIkt <- t(CIkt) 
 
-
+if(tau.res == TRUE){
 
  if(x$BivD %in% x$BivD2){ 
  
@@ -326,8 +337,22 @@ CIkt <- rowQuantiles(taus, probs = c(prob.lev/2,1-prob.lev/2), na.rm = TRUE)
                                 }
  }
 
+}
 
 
+ if(x$BivD %in% x$BivD2){ 
+ 
+   if(length(x$theta) > 1){
+ 
+     if( length(x$teta2) != 0) CItheta[x$teta.ind2, ] <- -CItheta[x$teta.ind2, ]; CItheta[x$teta.ind2, c(1,2)] <- CItheta[x$teta.ind2, c(2,1)] 
+                                 
+                          }else{
+ 
+     if( length(x$teta2) != 0) CItheta <- -CItheta; CItheta[, c(1,2)] <- CItheta[, c(2,1)]
+                                 
+                                }
+ }
+
 
 
 
@@ -423,20 +448,17 @@ if(x$margins[1] %in% cont3par) nus <- enu.tr(X4%*%t(bs1[,(x$X1.d2 + x$X3.d2 + 1)
 if(  is.null(x$X3) ){
    if(x$margins[1] %in% cont2par){
             sigma2s <- esp.tr(bs1[, lf1], x$VC$margins[1])$vrb 
-            sigma2s <- matrix(rep(sigma2s, each = dim(eta1s)[1]), ncol = n.sim, byrow = FALSE)
                                  }
    
    if(x$margins[1] %in% cont3par){
             sigma2s <- esp.tr(bs1[, lf1-1], x$VC$margins[1])$vrb
             nus     <- enu.tr(bs1[, lf1], x$VC$margins[1])$vrb
-            sigma2s <- matrix(rep(sigma2s, each = dim(eta1s)[1]), ncol = n.sim, byrow = FALSE)
-            nus     <- matrix(rep(nus, each = dim(eta1s)[1]), ncol = n.sim, byrow = FALSE)
 
                                  }
                     }                     
    
                        
-p1s <- matrix( distrHsAT(y1, eta1s, sigma2s, nus, x$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2   , dim(eta1s)[1], n.sim)
+p1s <- distrHsAT(y1, eta1s, sigma2s, nus, x$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2   
 p2s <- probmS( X2%*%t(bs2[,1:x$X2.d2]), x$VC$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pr 
 
 p12s <- p1s*p2s
@@ -450,7 +472,7 @@ if(cond == 2) p12s <- p1s
 } # independence
 
 
-list(p12 = p12, p12s = p12s, p1 = p1, p2 = p2, p3 = NULL, CIkt = CIkt, tau = tau)
+list(p12 = p12, p12s = matrix(p12s, 1, length(p12s)), p1 = p1, p2 = p2, p3 = NULL, CItau = CIkt, tau = tau, CItheta = CItheta, theta = theta)
 
 
 }
