@@ -1,11 +1,11 @@
 ppROY <- function(x){
 
-  cont1par <- c("PO","ZTP","DGP0","probit","logit","cloglog","GEVlink")  
-  cont2par <- c("N","N2","GU","rGU","LO","LN","WEI","GO","iG","GA","GA2","GAi","BE","FISK","NBI", "NBII","NBIa", "NBIIa","PIG","GP","GPII","GPo","DGP","DGPII")  
+  cont1par <- c("P","tP","DGP0","probit","logit","cloglog","GEVlink")  
+  cont2par <- c("N","N2","GU","rGU","LO","LN","WEI","GO","IG","GA","GA2","GAi","BE","FISK","tNBI", "tNBII","tPIG","NBI", "NBII","PIG","GP","GPII","GPo","DGP","DGPII")  
   cont3par <- c("DAGUM","SM","DEL","SICHEL","GGA","TW")   
 
   if(x$BivD1=="FGM")          {cop1 <- "FGM"                                     ;lind1 <- "atanh"} 
-  if(x$BivD1=="T")            {cop1 <- paste("Student-t (dof = ",format(x$dof12.a, digits=3),")",sep=""); lind1 <- "atanh"} 
+  if(x$BivD1=="T")            {cop1 <- "Student-t"                               ;lind <- "atanh"} # {cop1 <- paste("Student-t (dof = ",format(x$dof12.a, digits=3),")",sep=""); lind1 <- "atanh"} 
   if(x$BivD1=="AMH")          {cop1 <- "AMH"                                     ;lind1 <- "atanh"} 
   if(x$BivD1=="N")            {cop1 <- "Gaussian"                                ;lind1 <- "atanh"} 
   if(x$BivD1=="F")            {cop1 <- "Frank"                                   ;lind1 <- "identity"}       
@@ -45,7 +45,7 @@ ppROY <- function(x){
   if(x$BivD1=="G180G270")     {cop1 <- "180\u00B0 Gumbel & 270\u00B0 Gumbel"     ;lind1 <- "log(\u00B7 - 1) & log(- \u00B7 - 1)"}    
  
   if(x$BivD2=="FGM")          {cop2 <- "FGM"                                     ;lind2 <- "atanh"} 
-  if(x$BivD2=="T")            {cop2 <- paste("Student-t (dof = ",format(x$dof13.a, digits=3),")",sep=""); lind2 <- "atanh"} 
+  if(x$BivD2=="T")            {cop2 <- "Student-t"                               ;lind <- "atanh"} # {cop2 <- paste("Student-t (dof = ",format(x$dof13.a, digits=3),")",sep=""); lind2 <- "atanh"} 
   if(x$BivD2=="AMH")          {cop2 <- "AMH"                                     ;lind2 <- "atanh"} 
   if(x$BivD2=="N")            {cop2 <- "Gaussian"                                ;lind2 <- "atanh"} 
   if(x$BivD2=="F")            {cop2 <- "Frank"                                   ;lind2 <- "identity"}       
@@ -90,7 +90,7 @@ ppROY <- function(x){
     
     
     
-  mml <- c("LN","WEI","GO","iG","GA","GA2","GGA","DAGUM","SM","FISK","NBI","NBII","NBIa","NBIIa","PIG","PO","DGP0","ZTP","GP","GPII","GPo","DGP","DGPII","TW")  
+  mml <- c("LN","WEI","GO","IG","GA","GA2","GGA","DAGUM","SM","FISK","tNBI","tNBII","tPIG","NBI","NBII","PIG","P","DGP0","tP","GP","GPII","GPo","DGP","DGPII","TW")  
   
   
   
