@@ -15,20 +15,20 @@ print.SemiParBIV <- function(x, ...){
  doff <- "log(\u00B7 - 2)"
 
  bin.link <- x$bl
- cp <- "  theta = "; as.p <- x$theta.a
- main.t <- "\nCOPULA:  "     
+ cp <- "theta = "; as.p <- x$theta.a
+ main.t <- "\nCOPULA:"     
  cat(main.t,cop) 
   
  pscr0(x, type = "copSS")  
   
 
   cat("\n\nEQUATION 1")
-  cat("\nLink function for mu.1:",m1l,"\n")
+  cat("\nLink function for mu1:",m1l,"\n")
   cat("Formula: "); print(x$formula[[1]])
 
   cat("\nEQUATION 2")
   
-  cat("\nLink function for mu.2:",m2l,"\n")
+  cat("\nLink function for mu2:",m2l,"\n")
   cat("Formula: "); print(x$formula[[2]])
   
   
@@ -45,7 +45,7 @@ print.SemiParBIV <- function(x, ...){
   
 
   cat("\nEQUATION 3")
-  if(x$margins[2] != "BE") cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n") 
+  if(x$margins[2] != "BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n") 
   cat("Formula: ");  print(x$formula[[3]]) 
   
 
@@ -61,7 +61,7 @@ print.SemiParBIV <- function(x, ...){
   cat("\nEQUATION 3")
   
   #if(!(x$margins[2] %in% c("TW"))) 
-  cat("\nLink function for sigma:","log","\n") #else cat("\nLink function for sigma:","qlogis","\n")  
+  cat("\nLink function for sigma2:","log","\n") #else cat("\nLink function for sigma2:","qlogis","\n")  
 
   
   #cat("\nLink function for sigma:","log","\n") 
@@ -69,8 +69,8 @@ print.SemiParBIV <- function(x, ...){
   
   
   cat("\nEQUATION 4")
-  if(x$margins[2] %in% c("DAGUM","SM")) cat("\nLink function for nu:","log","\n")  
-  if(x$margins[2] %in% c("TW")) cat("\nLink function for nu:","qlogis","\n")  
+  if(x$margins[2] %in% c("DAGUM","SM")) cat("\nLink function for nu2:","log","\n")  
+  if(x$margins[2] %in% c("TW")) cat("\nLink function for nu2:","qlogis","\n")  
   
   cat("Formula: "); print(x$formula[[4]]) 
     
@@ -89,12 +89,12 @@ print.SemiParBIV <- function(x, ...){
   
   
   
-  if(x$Model %in% c("B","BPO") && x$margins[2] %in% cont1par) cat("n = ",x$n,cp,format(as.p, digits=3),"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
+  if(x$Model %in% c("B","BPO") && x$margins[2] %in% cont1par) cat(cp,format(as.p, digits=3),"\nn = ",x$n,"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
   if(x$Model == "BPO0")                                       cat("n = ",x$n,"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
-  if(x$Model == "BSS")                                        cat("n = ",x$n,"  n.sel = ",x$n.sel,cp,format(as.p, digits=3),"\ntotal edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
+  if(x$Model == "BSS")                                        cat(cp,format(as.p, digits=3),"\nn = ",x$n,"  n.sel = ",x$n.sel,"\ntotal edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
     
-  if(x$Model=="B" && x$margins[2] %in% cont2par ) cat("n = ",x$n,"  sigma = ",x$sigma2.a, cp, format(as.p, digits=3),"\ntotal edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
-  if(x$Model=="B" && x$margins[2] %in% cont3par ) cat("n = ",x$n,"  sigma = ",x$sigma2.a, "  nu = ",x$nu.a, "\ntheta = ", format(as.p, digits=3),"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
+  if(x$Model=="B" && x$margins[2] %in% cont2par ) cat("sigma2 = ",x$sigma2.a, "\ntheta = ", format(as.p, digits=3),"\nn = ",x$n,"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
+  if(x$Model=="B" && x$margins[2] %in% cont3par ) cat("sigma2 = ",x$sigma2.a, "  nu2 = ",x$nu.a, "\ntheta = ", format(as.p, digits=3),"\nn = ",x$n,"  total edf = ",format(x$t.edf, digits=3),"\n\n", sep="")
 
 
 
