@@ -12,15 +12,15 @@ print.gjrm <- function(x, ...){
  m2l      <- ppR$m2l 
 
   cp <- "theta = "; as.p <- x$theta.a
-  s1 <- "sigma.1 = "; s1.p <- x$sigma21.a
-  s2 <- "sigma.2 = "; s2.p <- x$sigma22.a  
-  n1 <- "nu.1 = "; n1.p <- x$nu1.a
-  n2 <- "nu.2 = "; n2.p <- x$nu2.a   
+  s1 <- "sigma1 = "; s1.p <- x$sigma21.a
+  s2 <- "sigma2 = "; s2.p <- x$sigma22.a  
+  n1 <- "nu1 = "; n1.p <- x$nu1.a
+  n2 <- "nu2 = "; n2.p <- x$nu2.a   
   
   doff <- "log(\u00B7 - 2)"
   
 
-  cat("\nCOPULA:  ",cop)
+  cat("\nCOPULA:",cop)
   
   
   pscr0(x, type = "copR")    
@@ -29,14 +29,14 @@ print.gjrm <- function(x, ...){
 
 
   cat("\n\nEQUATION 1")
-  if(x$surv.flex == FALSE )                                             cat("\nLink function for mu.1:",m1l,"\n")
-  if(x$surv.flex == TRUE && x$VC$margins[1] %in% c(x$VC$m2,x$VC$m3) )   cat("\nLink function for mu.1:",m1l,"\n")
+  if(x$surv.flex == FALSE )                                             cat("\nLink function for mu1:",m1l,"\n")
+  if(x$surv.flex == TRUE && x$VC$margins[1] %in% c(x$VC$m2,x$VC$m3) )   cat("\nLink function for mu1:",m1l,"\n")
   if(x$surv.flex == TRUE && !(x$VC$margins[1] %in% c(x$VC$m2,x$VC$m3))) cat("\n")
 
   cat("Formula: "); print(x$gam1$formula) 
   
   cat("\nEQUATION 2") 
-  if(x$surv.flex == FALSE) cat("\nLink function for mu.2:",m2l,"\n")
+  if(x$surv.flex == FALSE) cat("\nLink function for mu2:",m2l,"\n")
   if(x$surv.flex == TRUE)  cat("\n")  
   cat("Formula: "); print(x$gam2$formula) 
   
@@ -60,11 +60,11 @@ if(x$BivD == "T" && x$VC$margins[1] %in% c(x$VC$m2,x$VC$m3) && x$VC$margins[2] %
   
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
+  if(x$margins[1] !="BE") cat("\nLink function for sigma1:","log","\n") else cat("\nLink function for sigma1:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]])   
   
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n") 
+  if(x$margins[2] !="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[4]])   
   
   cat("\nEQUATION 5")
@@ -83,19 +83,19 @@ if(x$BivD == "T" && x$VC$margins[1] %in% c(x$VC$m2,x$VC$m3) && x$VC$margins[2] %
 if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
      
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma.1:","log","\n") 
+  cat("\nLink function for sigma1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]]) 
      
   cat("\nEQUATION 4")
-  cat("\nLink function for sigma.2:","log","\n") 
+  cat("\nLink function for sigma2:","log","\n") 
   cat("Formula: "); print(x$formula[[4]])  
   
   cat("\nEQUATION 5")
-  cat("\nLink function for nu.1:","log","\n") 
+  cat("\nLink function for nu1:","log","\n") 
   cat("Formula: "); print(x$formula[[5]])  
      
   cat("\nEQUATION 6")
-  cat("\nLink function for nu.2:","log","\n") 
+  cat("\nLink function for nu2:","log","\n") 
   cat("Formula: "); print(x$formula[[6]])    
   
   cat("\nEQUATION 7")
@@ -118,15 +118,15 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
      if( x$margins[1] %in% cont3par && x$margins[2] %in% cont2par){
      
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma.1:","log","\n") 
+  cat("\nLink function for sigma1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])   
      
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")
+  if(x$margins[2] !="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n")
   cat("Formula: "); print(x$formula[[4]])  
   
   cat("\nEQUATION 5")
-  cat("\nLink function for nu.1:","log","\n") 
+  cat("\nLink function for nu1:","log","\n") 
   cat("Formula: "); print(x$formula[[5]]) 
          
   cat("\nEQUATION 6")
@@ -151,15 +151,15 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
        
        
     cat("\nEQUATION 3")
-    if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n")
+    if(x$margins[1] !="BE") cat("\nLink function for sigma1:","log","\n") else cat("\nLink function for sigma1:","qlogis","\n")
     cat("Formula: "); print(x$formula[[3]])  
        
     cat("\nEQUATION 4")
-    cat("\nLink function for sigma.2:","log","\n") 
+    cat("\nLink function for sigma2:","log","\n") 
     cat("Formula: "); print(x$formula[[4]]) 
        
     cat("\nEQUATION 5")
-    cat("\nLink function for nu.2:","log","\n") 
+    cat("\nLink function for nu2:","log","\n") 
     cat("Formula: "); print(x$formula[[5]])      
     
     cat("\nEQUATION 6")
@@ -193,7 +193,7 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
   
   
   cat("\nEQUATION 3")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n") 
+  if(x$margins[2] !="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]])  
   
  
@@ -212,11 +212,11 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
        
 
     cat("\nEQUATION 3")
-    cat("\nLink function for sigma.2:","log","\n") 
+    cat("\nLink function for sigma2:","log","\n") 
     cat("Formula: "); print(x$formula[[3]]) 
        
     cat("\nEQUATION 4")
-    cat("\nLink function for nu.2:","log","\n") 
+    cat("\nLink function for nu2:","log","\n") 
     cat("Formula: "); print(x$formula[[4]])     
     
     cat("\nEQUATION 5")
@@ -234,11 +234,11 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
   
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
+  if(x$margins[1] !="BE") cat("\nLink function for sigma1:","log","\n") else cat("\nLink function for sigma1:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]])   
   
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n") 
+  if(x$margins[2] !="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[4]])   
   
   cat("\nEQUATION 5")
@@ -252,7 +252,7 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
   
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
+  if(x$margins[1] !="BE") cat("\nLink function for sigma1:","log","\n") else cat("\nLink function for sigma1:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]])   
     
   cat("\nEQUATION 4")
@@ -265,11 +265,11 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
   
 
   cat("\nEQUATION 3")
-  if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n") 
+  if(x$margins[1] !="BE") cat("\nLink function for sigma1:","log","\n") else cat("\nLink function for sigma1:","qlogis","\n") 
   cat("Formula: "); print(x$formula[[3]]) 
   
   cat("\nEQUATION 4")
-  cat("\nLink function for nu.1:","log","\n") 
+  cat("\nLink function for nu1:","log","\n") 
   cat("Formula: "); print(x$formula[[4]])  
     
   cat("\nEQUATION 5")
@@ -285,19 +285,19 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
 if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
      
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma.1:","log","\n") 
+  cat("\nLink function for sigma1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])  
      
   cat("\nEQUATION 4")
-  cat("\nLink function for sigma.2:","log","\n") 
+  cat("\nLink function for sigma2:","log","\n") 
   cat("Formula: "); print(x$formula[[4]]) 
   
   cat("\nEQUATION 5")
-  cat("\nLink function for nu.1:","log","\n") 
+  cat("\nLink function for nu1:","log","\n") 
   cat("Formula: "); print(x$formula[[5]])  
      
   cat("\nEQUATION 6")
-  cat("\nLink function for nu.2:","log","\n") 
+  cat("\nLink function for nu2:","log","\n") 
   cat("Formula: "); print(x$formula[[6]])    
   
   cat("\nEQUATION 7")
@@ -313,15 +313,15 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
      if( x$margins[1] %in% cont3par && x$margins[2] %in% cont2par){
      
   cat("\nEQUATION 3")
-  cat("\nLink function for sigma.1:","log","\n") 
+  cat("\nLink function for sigma1:","log","\n") 
   cat("Formula: "); print(x$formula[[3]])   
      
   cat("\nEQUATION 4")
-  if(x$margins[2] !="BE") cat("\nLink function for sigma.2:","log","\n") else cat("\nLink function for sigma.2:","qlogis","\n")
+  if(x$margins[2] !="BE") cat("\nLink function for sigma2:","log","\n") else cat("\nLink function for sigma2:","qlogis","\n")
   cat("Formula: "); print(x$formula[[4]])  
   
   cat("\nEQUATION 5")
-  cat("\nLink function for nu.1:","log","\n") 
+  cat("\nLink function for nu1:","log","\n") 
   cat("Formula: "); print(x$formula[[5]]) 
          
   cat("\nEQUATION 6")
@@ -341,15 +341,15 @@ if( x$margins[1] %in% cont3par && x$margins[2] %in% cont3par){
        
        
     cat("\nEQUATION 3")
-    if(x$margins[1] !="BE") cat("\nLink function for sigma.1:","log","\n") else cat("\nLink function for sigma.1:","qlogis","\n")
+    if(x$margins[1] !="BE") cat("\nLink function for sigma1:","log","\n") else cat("\nLink function for sigma1:","qlogis","\n")
     cat("Formula: "); print(x$formula[[3]])  
        
     cat("\nEQUATION 4")
-    cat("\nLink function for sigma.2:","log","\n") 
+    cat("\nLink function for sigma2:","log","\n") 
     cat("Formula: "); print(x$formula[[4]]) 
        
     cat("\nEQUATION 5")
-    cat("\nLink function for nu.2:","log","\n") 
+    cat("\nLink function for nu2:","log","\n") 
     cat("Formula: "); print(x$formula[[5]])      
     
     cat("\nEQUATION 6")
