@@ -1,24 +1,21 @@
-resp.check <- function(y, margin = "N", 
-                           main = "Histogram and Density of Response",
-                           xlab = "Response", print.par = FALSE, plots = TRUE, 
+resp.check <- function(y, margin = "N", print.par = FALSE, plots = TRUE, 
                            loglik = FALSE, os = FALSE, 
-                           intervals = FALSE, n.sim = 100, prob.lev = 0.05, 
                            i.f = FALSE, 
-                           min.dn = 1e-40, min.pr = 1e-16, max.pr = 0.999999, ...){
+                           min.dn = 1e-40, min.pr = 1e-16, max.pr = 0.999999, left.trunc = 0){
 
-m2 <- c("N","GU","rGU","LO","LN","WEI","iG","GA","GAi","BE","FISK","GP","GPII","GPo")
+m2 <- c("N","GU","rGU","LO","LN","WEI","IG","GA","GAi","BE","FISK","GP","GPII","GPo")
 m3 <- c("DAGUM","SM","TW")
 nu <- NULL
-m1d  <- c("PO","ZTP","DGP0")
-m2d  <- c("NBI", "NBII","NBIa", "NBIIa","PIG","DGP","DGPII")
+m1d  <- c("P","tP","DGP0")
+m2d  <- c("tNBI", "tNBII","tPIG","NBI", "NBII","PIG","DGP","DGPII")
 m3d  <- c("DEL","SICHEL")
 
 y1m <- NA
 y <- as.numeric( na.omit(y) )
 
-if(!(margin %in% c(m2,m3,m1d,m2d)) ) stop("Error in margin value. It should be one of:\nN, GU, rGU, LO, LN, WEI, iG, GA, DAGUM, TW, SM, BE, FISK, NBI, NBII, PIG, PO, ZTP, GP, GPII, GPo, DGP, DGPII, DGP0.") 
+if(!(margin %in% c(m2,m3,m1d,m2d)) ) stop("Error in margin value. It should be one of:\nN, GU, rGU, LO, LN, WEI, IG, GA, DAGUM, TW, SM, BE, FISK, NBI, NBII, PIG, P, tP, tNBI, tNBII, tPIG, GP, GPII, GPo, DGP, DGPII, DGP0.") 
 
-if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK") && min(y, na.rm = TRUE) <= 0) stop("The response must be positive.")
+if(margin %in% c("LN","WEI","IG","GA","GAi","DAGUM","SM","FISK") && min(y, na.rm = TRUE) <= 0) stop("The response must be positive.")
 if(margin %in% c("TW") && min(y, na.rm = TRUE) < 0) stop("The response must be > = 0.")
 
 if(margin %in% c("BE") && (min(y, na.rm = TRUE) <= 0 || max(y, na.rm = TRUE) >= 1) ) stop("The response must be in the interval (0,1).")
@@ -29,7 +26,7 @@ if(margin %in% c("BE") && (min(y, na.rm = TRUE) <= 0 || max(y, na.rm = TRUE) >=
     is.wholenumber <- function(x, tol = .Machine$double.eps^0.5)  abs(x - round(x)) < tol
     if(sum(as.numeric(is.wholenumber(y))) != length(y)) stop("The response must be discrete.")     
     }
-    if(margin %in% c("ZTP") && min(y, na.rm = TRUE) < 1) stop("The response must be greater than 0.") 
+    if(margin %in% c("tP","tNBI", "tNBII","tPIG") && min(y, na.rm = TRUE) < (left.trunc + 1)) stop("The response must be greater than the truncation point.") 
     
 
 
@@ -40,28 +37,28 @@ if(margin == "LN") y <- log(y)
 
 margins <- c(margin, margin) # not important to chance probit here
 
-VC <- list(X1 = matrix(1, nrow = length(y), ncol = 1), X1.d2 = 1,
+VC <- list(X1 = matrix(1, nrow = length(y), ncol = 1), X1.d2 = 1, offset = 0, 
            X2 = NULL, X2.d2 = 1,
            X3 = NULL, X3.d2 = 1, robust = FALSE,
            l.sp1 = 0, l.sp2 = 0, l.sp3 = 0, l.sp4 = 0, l.sp5 = 0, l.sp6 = 0, l.sp7 = 0, l.sp8 = 0, l.sp9 = 0, 
            weights = 1, m2 = m2, m3 = m3, m1d = m1d, m2d = m2d, m3d = m3d, 
            margins = margins, fp = TRUE,
            extra.regI = "t", Cont = "NO", ccss = "no", triv = FALSE, surv = FALSE, zero.tol = 1e-02, 
-           min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)
+           min.dn = min.dn, min.pr = min.pr, max.pr = max.pr, left.trunc = left.trunc)
 
 ps <- list(S.h = 0, S.h1 = 0, S.h2 = 0)
 
 respvec <- list(y1 = y)
            
-if( margin %in% c("PO","ZTP") )         st.v <- c( log( mean((y + mean(y))/2) ) )           
-if( margin %in% c("NBI","NBIa","PIG") ) st.v <- c( log(mean((y + mean(y))/2)), log( max( (var(y) - mean(y))/mean(y)^2, 0.1) ) )
-if( margin %in% c("NBII","NBIIa") )     st.v <- c( log(mean((y + mean(y))/2)), log( max( (var(y)/mean(y)) - 1, 0.1) ) )    
+if( margin %in% c("P","tP") )          st.v <- c( log( mean((y + mean(y))/2) ) )           
+if( margin %in% c("NBI","PIG","tNBI","tPIG") ) st.v <- c( log(mean((y + mean(y))/2)), log( max( (var(y) - mean(y))/mean(y)^2, 0.1) ) )
+if( margin %in% c("NBII","tNBII") )     st.v <- c( log(mean((y + mean(y))/2)), log( max( (var(y)/mean(y)) - 1, 0.1) ) )    
 if( margin %in% c("DEL") )              st.v <- c( log(mean((y + mean(y))/2)), log( max( (var(y) - mean(y))/mean(y)^2, 0.1) ), qlogis(0.5) )  
 if( margin %in% c("SICHEL") )           st.v <- c( log(mean((y + mean(y))/2)), log( max( (var(y) - mean(y))/mean(y)^2, 0.1) ), -0.5 )    
 if( margin %in% c("N","LN") )           st.v <- c( mean((y + mean(y))/2) ,           log( var(y) ) )  
 if( margin %in% c("N2") )               st.v <- c( mean((y + mean(y))/2) ,           log( sqrt(var(y)) ) )  
 if( margin %in% c("LO") )               st.v <- c( mean((y + mean(y))/2) ,           log(  3*var(y)/pi^2 ) )  
-if( margin %in% c("iG") )               st.v <- c( log( mean((y + mean(y))/2) ) , log( var(y)/mean(y)^3)  )    
+if( margin %in% c("IG") )               st.v <- c( log( mean((y + mean(y))/2) ) , log( var(y)/mean(y)^3)  )    
 if( margin %in% c("GU") )               st.v <- c( mean(y) + 0.57722*sqrt(var(y)/1.64493) ,  log(6*var(y)/pi^2) )    
 if( margin %in% c("rGU") )              st.v <- c( mean(y) - 0.57722*sqrt(var(y)/1.64493) ,  log(6*var(y)/pi^2) )   
 if( margin %in% c("WEI") )              st.v <- c( log( mean( exp(log(y) + 0.5772/(1.283/sqrt(var(log(y))))) )  ) , log( ( 1.283/sqrt(var(log(y))) )^2 ) ) 
@@ -135,26 +132,30 @@ if(plots == TRUE){ ##
 if(margin == "LN") y <- exp(y)
 
 
-    if(margin %in% c("ZTP","DGP","DGPII","DGP0")){
-     
-    ly1 <- length(y)
-    y1m <- list()
-    my1 <- max(y)
-    for(i in 1:ly1){ y1m[[i]] <- seq(1, y[i]); length(y1m[[i]]) <- my1} 
-    y1m <- do.call(rbind, y1m)  
-    
-    if(max(y) > 170) y1m <- mpfr( y1m, pmax(53, getPrec(y))) 
+    if(margin %in% c("DGP","DGPII","DGP0")) stop("This function is not suitable for the chosen distribution. \nGet in touch for more info.")
 
-     
-    }
+    #if(margin %in% c("ZTP","DGP","DGPII","DGP0")){
+    # 
+    #ly1 <- length(y)
+    #y1m <- list()
+    #my1 <- max(y)
+    #for(i in 1:ly1){ y1m[[i]] <- seq(1, y[i]); length(y1m[[i]]) <- my1} 
+    #y1m <- do.call(rbind, y1m)  
+    #
+    #if(max(y) > 170) y1m <- mpfr( y1m, pmax(53, getPrec(y))) 
+    #
+    # 
+    #}
 
     
 
 
 if(margin %in% m2)   pp <-      distrHsAT(y, univfit$argument[1], esp.tr(univfit$argument[2], margin)$vrb, 1, margin2 = margin, min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)
 if(margin %in% m3)   pp <-      distrHsAT(y, univfit$argument[1], esp.tr(univfit$argument[2], margin)$vrb, enu.tr(univfit$argument[3], margin)$vrb, margin2 = margin, min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)
-if(margin %in% m1d)  pp <- distrHsATDiscr(y, univfit$argument[1], 1, 1, margin2 = margin, y2m = y1m, robust = FALSE, min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)
-if(margin %in% m2d)  pp <- distrHsATDiscr(y, univfit$argument[1], esp.tr(univfit$argument[2], margin)$vrb, 1, margin2 = margin, y2m = y1m, robust = FALSE, min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)
+if(margin %in% m1d)  pp <- distrHsATDiscr(y, univfit$argument[1], 1, 1, margin2 = margin, y2m = y1m, robust = FALSE, min.dn = min.dn, min.pr = min.pr, 
+                                          max.pr = max.pr, left.trunc = left.trunc)
+if(margin %in% m2d)  pp <- distrHsATDiscr(y, univfit$argument[1], esp.tr(univfit$argument[2], margin)$vrb, 1, margin2 = margin, y2m = y1m, robust = FALSE, 
+                                          min.dn = min.dn, min.pr = min.pr, max.pr = max.pr, left.trunc = left.trunc)
 
 
 p <- pp$p2
@@ -163,24 +164,26 @@ d <- pp$pdf2
 if(margin %in% c(m1d,m2d)) p <- runif(y, p - d, p)
 
 
-par(mfrow = c(1, 2))
-hist(y, freq = FALSE, ylim=c(0, max(d, hist(y, plot = FALSE)$density) ),
-     main=main,
-     xlab=xlab, ...)
-
-lines(sort(y),d[order(y)],lwd=2)
+#par(mfrow = c(1, 2))
+#hist(y, freq = FALSE, ylim=c(0, max(d, hist(y, plot = FALSE)$density) ),
+#     main=main,
+#     xlab=xlab, ...)
+#
+#lines(sort(y),d[order(y)],lwd=2)
 
 
 if(any(is.na(p)) == TRUE) stop("It is not possible to produce a QQ-plot.\nThe chosen distribution (unconditional on covariates)\nis not probably a good fit.")
 
 
-if(intervals == FALSE){qqnorm(qnorm(p)); abline(0, 1, col = "red")}
-if(intervals == TRUE) {univfit$y2 <- y
-                       univfit$Cont <- "NO" 
-                       univfit$VC$ccss <- "no"
-                       univfit$univar.gamlss <- FALSE
-                       univfit$n <- length(y) 
-                       int.postcheck(univfit, margin, n.rep = n.sim, prob.lev = prob.lev, y2m = y1m)}
+#if(intervals == FALSE){
+qqnorm(qnorm(p)); abline(0, 1, col = "red")
+#}
+#if(intervals == TRUE) {univfit$y2 <- y
+#                       univfit$Cont <- "NO" 
+#                       univfit$VC$ccss <- "no"
+#                       univfit$univar.gamlss <- FALSE
+#                       univfit$n <- length(y) 
+#                       int.postcheck(univfit, margin, n.rep = n.sim, prob.lev = prob.lev, y2m = y1m)}
 
 
 
@@ -199,7 +202,7 @@ if(print.par == TRUE && os == FALSE && i.f == FALSE) print( univfit$argument )
 if(print.par == TRUE && os == TRUE && i.f == FALSE){         
          
 mu    <- eta.tr(univfit$argument[1], margin)
-mupos <- c("LN","WEI","iG","GA","DAGUM","SM","TW","FISK",m1d,m2d,m3d)
+mupos <- c("LN","WEI","IG","GA","DAGUM","SM","TW","FISK",m1d,m2d,m3d)
 mub   <- c("BE")
 if(margin %in% mupos) mu <- exp(mu)
 if(margin %in% mub)   mu <- plogis(mu)
